| plotSpecLs | R Documentation |
Plotting method for objects of class "spec.ls".
plotSpecLs(x, add = FALSE, ci = 0.95, log = c("yes", "dB", "no"), xlab
= "frequency", ylab = NULL, type = "l", main = NULL, sub = NULL, ...)
x |
an object of class |
add |
logical. If |
ci |
Coverage probability for confidence interval. Plotting of
the confidence bar is omitted unless |
log |
If |
xlab |
the x label of the plot. |
ylab |
the y label of the plot. |
type |
the type of plot to be drawn, defaults to lines. |
main |
overall title for the plot. |
sub |
a sub title for the plot. |
... |
Further graphical parameters. |
Called for its side effect of producing a plot. Invisibly returns x (an object of class "spec.ls").
spec.ls
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.